modimport("scripts/waiter_kitchen.lua") -- food tags
modimport("scripts/waiter_menu.lua") -- recipe lists

local require = GLOBAL.require
local DST = GLOBAL.TheSim:GetGameID() == "DST"

GLOBAL.global("W101_FLOAT") -- For strict.lua to be happy, declares this as a global
GLOBAL.global("W101_DST_FLOAT") -- For strict.lua to be happy, declares this as a global
GLOBAL.global("W101_TEMP") -- For strict.lua to be happy, declares this as a global
GLOBAL.global("W101_CROPS") -- For strict.lua to be happy, declares this as a global
GLOBAL.global("W101_MEDS") -- For strict.lua to be happy, declares this as a global

GLOBAL.W101_FLOAT = 0 -- if set to 0 waiter prefabs do not float in water and are not affected by winds
GLOBAL.W101_DST_FLOAT = 0 -- if set to 0 waiter prefabs do not float in water (DST)
GLOBAL.W101_TEMP = 0 -- if set to 0 foods do not affect body temp
GLOBAL.W101_MEDS = 0 -- if set to 0 foods do not affect have antihistamine affect
GLOBAL.W101_CROPS = GetModConfigData("waiter_crops") + 0 -- forces this to numerical

W101_LEEK = GetModConfigData("waiter_garleekdrop") + 0 -- forces this to numerical
W101_TREES = GetModConfigData("waiter_treedrop") + 0 -- forces this to numerical
W101_VINES = GetModConfigData("waiter_vineydrop") + 0 -- forces this to numerical
-- This should force to numerical for old saves

print "@@@ Waiter101 Modmain BEGIN @@@"

W101_LANG = GetModConfigData("waiter_language") + 0 -- forces this to numerical

if W101_LANG == 1 then require "waiter_speech_port" -- names and food descriptions - Portugese / Brazil
 elseif W101_LANG == 2 then require "waiter_speech_pol" -- names and food descriptions - Polish
  else require "waiter_speech_eng" -- names and food descriptions - English
end

-- Apply the fix
-- Note: This must be called before any AddCookerRecipe calls
-- Note: This fix is not necessary with more recent versions of Don't Starve
-- modimport("scripts/cookpotfix.lua")

require "W101_tags"

--[[
	The code below is adapted from the API Examples mod: http://forums.kleientertainment.com/files/file/203-api-examples/
  ]]

Assets = {
    Asset("ANIM", "anim/grapricot_dried.zip"),
	Asset("ANIM", "anim/tomango_dried.zip"),
	Asset("ANIM", "anim/spiced_sausage.zip"),
	-- The following are loaded to help craft pot and similar mod with ingredients
	Asset("ATLAS", "images/food_tags.xml"), -- meant to replace/suppliment Craft Pot tags 
	
	-- Asset("IMAGE", "images/inventoryimages/zucchilli.tex"),
	-- Asset("ATLAS", "images/inventoryimages/zucchilli.xml"),
    -- Asset("ATLAS_BUILD", "images/inventoryimages/zucchilli.xml", 64),
	
	-- Asset("IMAGE", "images/inventoryimages/crop_atlas.tex"),
	-- Asset("ATLAS", "images/inventoryimages/crop_atlas.xml"),
    -- Asset("ATLAS_BUILD", "images/inventoryimages/crop_atlas.xml", 64),
}

PrefabFiles = {
-- ALL CORE PREFAB
	"ack_muffin",
-- Breads (x5)
	"nana_bread",
	"fruit_muffin",
	"hardtack",
	"shamcakes",
-- Cakes & Pies (x5)
	"cactus_cake", -- requires cactus
	"meringue",
	"sticky_bun",
	"tarte_tatin",
	"spiced_cake",
-- Candies (x5)
	"candied_bacon",
	"candied_fruit",
	"candied_nut",
	"mush_melon", -- ROG & SW only ; can be cooked ; see 'Extras'
	"candy_sponge", -- sponge toffee
-- Eggs (x4)
	"nopalito", -- requires cactus
	"omelette", -- spoils to mushy eggs ; see hidden recipes
	"salad_egg",
	"egg_foo_yung", -- spoils to mushy eggs ; see hidden recipes
	-- "??",
-- Fruits (x4)
	"fruit_truffle",  -- requires non-fat dairy
	"limonade",  -- Drink, requires frozen
	"fruit_leather",
	"limongelo",
	-- "??",
-- Iced Foods (x4) (foods that use two or more ice - very low benefits)
	"soup_broth",
	"soup_watercress",
	"juice_waterberry",
	"tea_floral",
	-- "soup_noodle", --(ice, ice, flour, any)
-- Meats (Beef) (x4)
	"braciole",
	"coldcuts", -- requires frozen
	"beef_butter",
	"beef_stirfry",
	"kiymali_pide", -- meat bread
-- Meats (Pork) (x5)
	"sausage_gravy",
	"sweet_n_sour",
    "spiced_ham",
	"spiced_sausage", -- can be cooked or dried ; see extras
	"dumpling_pork",
-- Meats (Seafood) (x5)
	"fish_n_chips",
	"stuffed_tomango",
	"surf_n_turf",
	"tentacicle", -- Requires Frozen
	"slurry_seafood",
-- Meats (Shelfish) (x4)
	"lobster_faked", -- SW only
	"shellfish_butter",
	"cake_crab", -- SW only
	"tempura_shrimp",
	"scallops_spicy",
-- Meats (Poultry) (x5)
	"beefalo_wings",
	"lo_mein_chicken",
	"rollatini",
	"picatta",
	"salad_waldorf",
-- Monster (x2)
	"beef_maxwell",
	"monster_burger",
	"durian_delight",
	"hakarl",
	--"??",
-- Mushrooms (x4)
	"citrus_mushroom",
	"mushroom_burger",
	"mushroom_medley", -- spoils to mushroom_malody ; see hidden recipes
	"mushroom_stew",
	-- "??",
-- Salads & Veggies	(x4)
	"salad_bloom",
	"salad_carrot",
	"salad_grape",
	"salad_yamion",
	-- "??",
-- Spiced Foods	(x4)
	"salad_spiced",
	"spiced_fish", -- Jjigae (Korean Stew)
	"spiced_rum",
	"dragon_roll",
	"piko_salsa",
-- Sandwiches	(x5)
	"sandwich_blt",
	"sandwich_blt_half",
	"sandwich_jam",
	"sandwich_jam_half",
	"sandwich_banana",
	"sandwich_banana_half",
	"sandwich_croque",
	"sandwich_croque_half",
	"sandwich_veggie",
	"sandwich_veggie_half",
-- Soups	(x5)
	"cactus_soup", -- requires cactus
	"soup_chowder",
	"gazpacho", -- requires frozen
	"gumbo",
	"soup_squash", -- requires nut
-- Snacks	(x3)
	"aloo_tiki",
	"twice_baked",
	"yamion_rings",
	"takoyaki",
	"popcorn_buttery",
	"leftovers",
-- Nuts and Seeds	(x3)
	"cheese_log", -- requires nut
	"nut_butter", -- requires nut
	"porridge", -- requires nut seed only ; spoils to gruel ; see extras
	"kung_pao", -- requires nut or seed
	-- "??",
-- Liquors (x5)
	"liquor", -- requires frozen
	"daiquiri", -- requires frozen
	"margarita", -- requires frozen
	"pina_colada", -- requires frozen
	"vino", -- requires frozen ; spoils to pinot_noir ; see extras 
-- Cookable Ingredients (x5)
	"fruit_syrup",
	"molasses", -- ROG & SW only
	"oleo",
	"coconut_milk", -- SW only
	"flour_ground",
-- Mystery Recipes	(x3)
    "mooncake_simple",
	"casserole",
	"mushy_eggs", -- 'bad' egg recipe, certain spoiled egg dishes
	"mushroom_malody", -- 'bad' mushroom recipe, spoiled mushroom medley
	-- "fritters", -- catchall for flour to make it give some return 
	-- "??",
-- Extras	(x5)
	"pinot_noir", -- from spoiled vino only
	"gruel", -- from spoiled porrige only
	"mush_melon_cooked", -- from cooked mush_melon only
	"sausage_cooked", -- from cooked spiced_sausage only
	"sausage_dried", -- from dried spiced_sausage only
-- OTHER ADD-INS (x24 total)
-- Mob_Drops (x2)
	"rocky_meat",
	"tentacle_meat",
-- Mob_Drops_Cooked (x2)
	"rocky_meat_cooked",
	"tentacle_meat_cooked",
-- Dried Farmables (x2)
	"grapricot_dried",
	"tomango_dried",
	-- "??",
-- Non-Famables	(x3)
	"rutabeeta_plant",
	"garleek",
	"papayanapple", -- SW only
-- Non-Famables_Cooked	(x2)	
	"garleek_cooked",
	"papayanapple_cooked", -- SW only
--[[
-- Crops_Seeds (x7)
	"grapricot_seeds",
	"guavacado_seeds",
	"limon_seeds",
	"rutabeeta_seeds",
	"tomango_seeds",
	"yamion_seeds",
	"zucchilli_seeds",
-- Farmables (x7)
	"grapricot",
	"guavacado",
	"limon",
	"rutabeeta",
	"tomango",
	"yamion",
	"zucchilli",
-- Farmables_Cooked (x7)
	"grapricot_cooked",
	"guavacado_cooked",
	"limon_cooked",
	"rutabeeta_cooked",
	"tomango_cooked",
	"yamion_cooked",
	"zucchilli_cooked",
	]]
	"waiter_seedcrops", -- this replaces the old way of making seeds and crops
}
 -- ADD antihistamine effect to certain recipes? 
 --[[
 NATURAL ANTIHISTAMINES -- NOTES
    bell peppers
    broccoli
    cantaloupe melon
    cauliflower
    *citrus fruits
    kiwifruit
    strawberries
    *tomatoes and tomato juice
    winter squash (includes pumpkin - does game? no)
	*Pineapple
	-- weaker found in:
    apples
    *berries
    *black tea
    broccoli
    *buckwheat tea
    *grapes
    Ginkgo biloba
    *green tea
    peppers
    *red onions
    red wine
 
 ]]
-- Turn on W101_FLOAT (Windblown and Floating physics) if Game is not DST AND either Capy or Porkland is enabled
if GLOBAL.TheSim:GetGameID()~="DST" then
	if GLOBAL.IsDLCEnabled(GLOBAL.CAPY_DLC) or GLOBAL.IsDLCEnabled(GLOBAL.PORKLAND_DLC) then 
		GLOBAL.W101_FLOAT=1
	else end
else end

-- Turn on W101_DST_FLOAT (Floating physics) if Game is DST AND BETA is enabled
if GLOBAL.TheSim:GetGameID()=="DST" and CurrentRelease.GreaterOrEqualTo( "R08_ROT_TURNOFTIDES" ) then
	-- and CurrentRelease.GreaterOrEqualTo( ReleaseID.IDs.R08_ROT_TURNOFTIDES ) then
		GLOBAL.W101_DST_FLOAT = 1
	else end
  
-- Turn on W101_TEMP (Food Temperature Components) if Game is DST, OR Capy, Porkland, or RoG is enabled
if GLOBAL.TheSim:GetGameID()=="DST" then 
	GLOBAL.W101_TEMP = 1
	elseif GLOBAL.IsDLCEnabled(GLOBAL.CAPY_DLC) or GLOBAL.IsDLCEnabled(GLOBAL.REIGN_OF_GIANTS) or GLOBAL.IsDLCEnabled(GLOBAL.PORKLAND_DLC) then
	GLOBAL.W101_TEMP = 1
else end

-- Turn on W101_MEDS (Antihistamines) if Game is not DST AND Porkland is enabled
if GLOBAL.TheSim:GetGameID()~="DST" then
	if GLOBAL.IsDLCEnabled(GLOBAL.PORKLAND_DLC) then 
		GLOBAL.W101_MEDS=1
	else end
else end

print "Crops"
print (GLOBAL.W101_CROPS)
print "Float"
print (GLOBAL.W101_FLOAT)
print "DST Float"
print (GLOBAL.W101_DST_FLOAT)
print "Temp"
print (GLOBAL.W101_TEMP)
print "Meds"
print (GLOBAL.W101_MEDS)

_G = GLOBAL
TUNING = _G.TUNING

--Tuning
local W101_QUAL = GetModConfigData("waiter_quality")
--[[
local W101_HEAL = GetModConfigData("waiter_healing")
local W101_SAN = GetModConfigData("waiter_sanity")
]]
--Calories
if  W101_QUAL < 0.9 then W101_QUAL = 1 end
if  W101_QUAL > 1.05 then W101_QUAL = 1 end

	TUNING.CALORIES_TINY = TUNING.CALORIES_TINY ^W101_QUAL -- berries 9.375
	TUNING.CALORIES_SMALL = TUNING.CALORIES_SMALL ^W101_QUAL -- veggies 12.5
	TUNING.CALORIES_MEDSMALL = TUNING.CALORIES_MEDSMALL ^W101_QUAL -- 18.75
	TUNING.CALORIES_MED = TUNING.CALORIES_MED ^W101_QUAL -- meat 25
	TUNING.CALORIES_LARGE = TUNING.CALORIES_LARGE ^W101_QUAL -- cooked meat 37.5
	TUNING.CALORIES_HUGE = TUNING.CALORIES_HUGE ^W101_QUAL -- crockpot foods? 75
	TUNING.CALORIES_SUPERHUGE = TUNING.CALORIES_SUPERHUGE ^W101_QUAL -- crockpot foods? 150

--Healing -- Tuning_Healing affects not just foods but other healing items... do not use at this time.
--[[
if  W101_HEAL < 0.9 then W101_HEAL = 1 end
if  W101_HEAL > 1.05 then W101_HEAL = 1 end

	TUNING.HEALING_TINY = TUNING.HEALING_TINY ^W101_HEAL -- 1
	TUNING.HEALING_SMALL = TUNING.HEALING_SMALL ^W101_HEAL -- 3
	TUNING.HEALING_MEDSMALL = TUNING.HEALING_MEDSMALL ^W101_HEAL -- 8
	TUNING.HEALING_MED = TUNING.HEALING_MED ^W101_HEAL -- 20
	TUNING.HEALING_MEDLARGE = TUNING.HEALING_MEDLARGE ^W101_HEAL -- 30
	TUNING.HEALING_LARGE = TUNING.HEALING_LARGE ^W101_HEAL -- 40
	TUNING.HEALING_HUGE = TUNING.HEALING_HUGE ^W101_HEAL -- 60
	TUNING.HEALING_SUPERHUGE = TUNING.HEALING_SUPERHUGE ^W101_HEAL -- 100
	]]
--[[
--SANITY -- Sanity changes are so slight since most sanity gives only +5... not necessary option
-- (check to see if affects other mechanics [darkness]? )
if  W101_SAN < 0.9 then W101_SAN = 1 end
if  W101_SAN > 1.05 then W101_SAN = 1 end
	TUNING.SANITY_SUPERTINY = TUNING.SANITY_SUPERTINY ^W101_SAN -- 1
	TUNING.SANITY_TINY = TUNING.SANITY_TINY ^W101_SAN-- 5
	TUNING.SANITY_SMALL = TUNING.SANITY_SMALL ^W101_SAN-- 10
	TUNING.SANITY_MED = TUNING.SANITY_MED ^W101_SAN-- 15
	TUNING.SANITY_MEDLARGE = TUNING.SANITY_MEDLARGE ^W101_SAN-- 20
	TUNING.SANITY_LARGE = TUNING.SANITY_LARGE ^W101_SAN-- 33
	TUNING.SANITY_HUGE = TUNING.SANITY_HUGE ^W101_SAN-- 50
]]

if W101_TREES > 1 then	
--adds the chance papayanapple drop to jungle trees, thanks to DarkXero for the code.
if GLOBAL.TheSim:GetGameID()~="DST" then
  if GLOBAL.IsDLCEnabled(GLOBAL.CAPY_DLC) or GLOBAL.IsDLCEnabled(GLOBAL.PORKLAND_DLC) then 
  
  local growablepostinit = false
local function jungletreepostinit(inst)
	if not growablepostinit then
		growablepostinit = true -- So it only runs once
		local growth_stages = inst.components.growable.stages
					
		local older_fn = growth_stages[2].fn -- Stage 2 is the normal stage
		growth_stages[2].fn = function(inst)
			older_fn(inst) -- This holds SetNormal with all its locals
			local chanceloot = inst.components.lootdropper.chanceloot or {}
			for i, v in ipairs(chanceloot) do
				if v.prefab == "bird_egg" and math.random() < 0.15 then
					v.prefab = "papayanapple"
					break
				end
			end
		end
			
		local old_fn = growth_stages[3].fn -- Stage 3 is the tall stage
		growth_stages[3].fn = function(inst)
			old_fn(inst) -- This holds SetTall with all its locals
			local chanceloot = inst.components.lootdropper.chanceloot or {}
			for i, v in ipairs(chanceloot) do
				if v.prefab == "bird_egg" and math.random() < 0.15 then
					v.prefab = "papayanapple"
					break
				elseif v.prefab == "cave_banana" and math.random() < 0.35 then
					v.prefab = "papayanapple"
					break
				end
			end
		end

	
	end
end
  
AddPrefabPostInit("jungletree", jungletreepostinit)  

end
end

else end

local guavadrop = false

if W101_TREES == 1 then guavadrop = true end
if W101_TREES == 3 then guavadrop = true end

--Guavacado Drop
--Add guavacado to trees (code provided by rons0n)

if GLOBAL.TheSim:GetGameID() =="DST" then
  
function GuavaPostInit(inst)    
	if GLOBAL.TheWorld.ismastersim then 
		local oldonfinish = inst.components.workable.onfinish
			inst.components.workable.onfinish = function(inst, chopper)            
				if chopper then 
				    if inst.components.growable then
						if inst.components.growable.stage > 2 then
						inst.components.lootdropper:AddChanceLoot("guavacado", 0.05)
					    elseif 	inst.components.growable.stage > 1 then
						inst.components.lootdropper:AddChanceLoot("guavacado", 0.03)
						end
					else
						inst.components.lootdropper:AddChanceLoot("guavacado", 0.02)
					end            
				end	
			oldonfinish(inst, chopper)        
		end    
	else end	
	return inst
end 

if guavadrop then
local guavatrees = {	
	"evergreen_sparse", 
	"marsh_tree"
	}
	for k,v in pairs(guavatrees) do AddPrefabPostInit(v, GuavaPostInit)
end


  end
else
function GuavaPostInit(inst)    
	
		local oldonfinish = inst.components.workable.onfinish
			inst.components.workable.onfinish = function(inst, chopper)            
				if chopper then 
				    if inst.components.growable then
						if inst.components.growable.stage > 2 then
						inst.components.lootdropper:AddChanceLoot("guavacado", 0.03)
					    elseif 	inst.components.growable.stage > 1 then
						inst.components.lootdropper:AddChanceLoot("guavacado", 0.02)
						end
					else
						inst.components.lootdropper:AddChanceLoot("guavacado", 0.01)
					end            
				end	
			oldonfinish(inst, chopper)        
		end    
		
	return inst
end 

if guavadrop then
local guavatrees = {	
	"evergreen_sparse", 
	"marsh_tree"
	}
	for k,v in pairs(guavatrees) do AddPrefabPostInit(v, GuavaPostInit)
end
 
end

end
--End Guavacado Drop

--function to spawn an extra item, code that provided by DarkXero.
local function SpawnDrop(inst, lootprefab)
	local loot = GLOBAL.SpawnPrefab(lootprefab)
	local x, y, z = inst.Transform:GetWorldPosition()
	loot.Transform:SetPosition(x, y, z)
	if GLOBAL.TheSim:GetGameID()~="DST" then
		if GLOBAL.IsDLCEnabled(GLOBAL.CAPY_DLC) or GLOBAL.IsDLCEnabled(GLOBAL.PORKLAND_DLC) then 
			inst:ApplyInheritedMoisture(loot) -- object is wet if parent object is wet, SW only
			
			if loot.components.inventoryitem then 
			loot.components.inventoryitem:OnLootDropped()
			end 
			
		end
	end
	local angle = math.random() * 2 * GLOBAL.PI
	local speed = (math.random() * 0.75) +1.5
	loot.Physics:SetVel(speed * math.cos(angle), GLOBAL.GetRandomWithVariance(8, 4), speed * math.sin(angle))
end

--adds the chance for tomango or zucchilli as additional drop to viney bush, thanks to DarkXero for the code.
if W101_VINES == 1 then	
AddPrefabPostInit("bush_vine", function(inst)

	local ThisSeason = 0  
	local OffSeason = 0  
	
	inst:ListenForEvent("hacked", function(inst, data)
		local season = DST and GLOBAL.TheWorld.state.season or GLOBAL.GetSeasonManager():GetSeason()
		-- local season = GLOBAL.GetSeasonManager():GetSeason()
        if season == GLOBAL.SEASONS.SUMMER or season == GLOBAL.SEASONS.DRY then ThisSeason = 0.05
		else ThisSeason = 0 end
		if season == GLOBAL.SEASONS.AUTUMN or season == GLOBAL.SEASONS.MILD or season == GLOBAL.SEASONS.TEMPERATE then OffSeason = 0.05
		else OffSeason = 0 end
		if math.random() < ( 0.04 + ThisSeason + OffSeason ) then -- 4% chance to drop; increases to 9% in Summer(Dry) or Autumn (Mild)
			if math.random() < ( 0.4 + (ThisSeason * 4) - (OffSeason * 2)) then SpawnDrop(inst, "tomango") else
				SpawnDrop(inst, "zucchilli") end -- 40% chance of Tomango, 60% in Summer(Dry) or 30% in Autumn (Mild), if not tomango then Zucchilli
			end
	end)
end)
else end

--[[
Adds a decreasing over time chance of Garleek Drop from Grass, ranging from 10% to 4%
	Chance as follows: Day 0 = 10%, Day 1 =7.5%; Day 2 = 6.5%, Day 7 = 5%, Day 15 = 4.5%, Day 33 = 4.2%, Day 171 = 4.0%
	During Spring chance increases by a flat 4%, much assistance in coding from Mobbstar
]]
if W101_LEEK > 0 then	
AddPrefabPostInit("grass", function(inst)
    local gdc = W101_LEEK
	local ThisSeason = 0    
	local daycount = 171 -- FOR DST sets 4% drop rate (uses actual daycount DS) : use 0 days to set at 10%
	
    inst:ListenForEvent("picked", function(inst, data)
	local season = DST and GLOBAL.TheWorld.state.season or GLOBAL.GetSeasonManager():GetSeason()
	
	-- local season = GLOBAL.GetSeasonManager():GetSeason()
	    if daycount > 15 and ( season == GLOBAL.SEASONS.SPRING or season == GLOBAL.SEASONS.GREEN or season == GLOBAL.SEASONS.LUSH) then ThisSeason = (0.02 +(0.02*gdc)) else ThisSeason = 0 end
		if GLOBAL.TheSim:GetGameID()~="DST" then
			daycount = GLOBAL.GetClock():GetNumCycles()
		end
		if math.random() <= ( (0.02 + (0.02 * gdc)) + ( gdc / ( 1 + ( (daycount*10) * 0.07)) *0.06 ) + (ThisSeason)) then
			SpawnDrop(inst, "garleek")
		end 
    end)
end)
else end

--[[
Adds a decreasing over time chance of Garleek Drop from Water Grass ranging from 3% to 2%
	Chance as follows: Day 0 = 3%, Day 1 =2.6%; Day 2 = 2.4%, Day 7 = 2.2%, Day 15 = 2.1%, Day 33 = 2.0%
	During Summer chance increases by a flat 2%, much assistance in coding from Mobbstar
]]
if W101_LEEK == "1" then	
if GLOBAL.TheSim:GetGameID()~="DST" then
  if GLOBAL.IsDLCEnabled(GLOBAL.CAPY_DLC) then 
  
  AddPrefabPostInit("grass_water", function(inst)
	local DrySeason = 0    
	local daycount = 171 -- 2% drop rate (unchanging in DST) : use 0 days to set at 3%
	
    inst:ListenForEvent("picked", function(inst, data)
	local season = DST and GLOBAL.TheWorld.state.season or GLOBAL.GetSeasonManager():GetSeason()
	
	-- local season = GLOBAL.GetSeasonManager():GetSeason()
	    if season == GLOBAL.SEASONS.SUMMER or season == GLOBAL.SEASONS.DRY then DrySeason = 0.02 else DrySeason = 0 end
		if GLOBAL.TheSim:GetGameID()~="DST" then
			daycount = GLOBAL.GetClock():GetNumCycles()
		end
		if math.random() <= ( 0.02 + ( 1 / ( 1 + ( (daycount*10) * 0.07)) *0.01 ) + DrySeason) then
			SpawnDrop(inst, "garleek")
		end 
    			
	end)
	
	end)

else end
else end
else end
 
-- Base Game NAMES and SPEECH moved to waiter_speech_eng.lua
	
-- RoG Enabled Characters
if GLOBAL.IsDLCEnabled(GLOBAL.REIGN_OF_GIANTS) or GLOBAL.TheSim:GetGameID()=="DST" then

-- DESCRIPTIONS.WATHGRITHR	
	-- Breads (x3)
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.NANA_BREAD = "A loaf of monkey food."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.FRUIT_MUFFIN = "Nothing in a muffin."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.HARDTACK = "Dried and tasteless, and definitely not meat."
	-- Cakes & Pies (x4)
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.CACTUS_CAKE = "I'm not much of a cake person."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.MERINGUE = "A waste of good eggs."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.STICKY_BUN = "I'll stick to meat."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.TARTE_TATIN = "Too bad its not a meat pie."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.SHAMCAKES = "These are not suitable for a warrior."
	-- Candies & Sugars (x4+)
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.CANDIED_BACON = "Sweetness and meatness."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.CANDIED_FRUIT = "I prefer sweetbread." -- Sweetbread : a culinary term for the thymus or neck
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.CANDIED_NUT = "I prefer sweetbread." -- Sweetbread : a culinary term for the thymus or neck
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.MUSH_MELON = "Good for toasting, but not for tasting."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.MUSH_MELON_COOKED = "I like putting them on skewers."
	-- Eggs (x4)
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.MUSHY_EGGS = "Egger my appetite." -- Norwegian- Egger : to incite
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.OMELETTE = "Eggja to eat now."  -- Old Norse- Eggja : to sharpen
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.NOPALITO = "Sword plant and hot egg."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.SALAD_EGG = "Is it really a salad?"
	-- Fruits (x4)
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.FRUIT_LEATHER = "It's not real leather."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.FRUIT_TRUFFLE = "Totally unimportant." -- Trifle : something of little importance
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.LIMONADE = "I do not feel good about it."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.LIMONGELO = "It moves, but it isn't alive."
	-- Meats (x4)
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.BRACIOLE = "Vegetables wrapped in meat."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.COLDCUTS = "Precooked meat on ice."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.SAUSAGE_GRAVY = "I love the sausage, the rest is just gravy."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.SWEET_N_SOUR = "It taste like victory."
	-- Meats (Fish) (x3)
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.SURF_N_TURF = "Twice the meat in one feast."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.FISH_N_CHIPS = "Fishmeat with chipped roots."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.STUFFED_TOMANGO = "I suppose it still counts as meat."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.LOBSTER_FAKED = "It would be better if bested in a butter battle." -- Literary reference: "Butter Battle Book" : by Doctor Seuss
	-- Meats (Poultry) (x3)
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.ROLLATINI = "Meat wrapped in vegetables."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.PICATTA = "Interesting flavor."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.BEEFALO_WINGS = "Lo! A beef wing!" -- Anagram of "Beefalo wing"
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.SALAD_WALDORF = "Is it still salad if there is meat in it?"
	-- Mushrooms (4+)
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.CITRUS_MUSHROOM = "Nasty mushrooms and nasty fruit on part of a spear."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.MUSHROOM_BURGER = "Mushrooms holding onto meat."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.MUSHROOM_MALODY = "Colorful, but I still won't eat it."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.MUSHROOM_MEDLEY = "Colorful, but I won't eat it."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.MUSHROOM_STEW = "Nasty mushrooms floating in cream."
	-- Salads (4)
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.SALAD_CARROT = "Not a speck of meat in sight."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.SALAD_GRAPE = "No reason to call it food without meat."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.SALAD_YAMION = "No. I yam not going to leek that." -- An onion is a type of leek 
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.SALAD_BLOOM = "Somehow this seems to have even less meat."
	-- Soups (x5)
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.GAZPACHO = "Gazpach-no."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.CACTUS_SOUP = "Sword plant soup."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.SOUP_CHOWDER = "Fishmeat stewed in cream."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.GUMBO = "Spicy stewed fishmeat."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.SOUP_SQUASH = "I'd have to be off my gourd to eat that." -- pmpkin and squash are types of gourd
	-- Snacks (x7 +)
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.ALOO_TIKI = "They would be good stuffed with meat."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.CHEESE_LOG = "No whey will I eat that." -- Whey : A liquid byproduct of making cheese
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.NUT_BUTTER = "Sweet and fat but still a nut."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.PORRIDGE = "This is inedible glop."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.GRUEL = "This is inedible goop."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.YAMION_RINGS = "Vegetable rings fried in fat."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.TWICE_BAKED = "I'm not sure there is enough meat in it."
	-- Liquor (x5 +1)
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.LIQUOR = "A noggin of mead, not meat." -- Mead : An alcoholic beverage
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.DAIQUIRI = "I didn't really like it very much." 
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.MARGARITA = "A drink with no meat in? I don't know the reason." -- Musical Reference : "Margaritaville" by Jimmy Buffett
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.PINA_COLADA = "I'm not much into health food." -- Musical Reference : "Escape (Pina Colada song)" by Rupert Holmes 
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.VINO = "Wine is just grape juice."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.PINT_NOIR = "Aged wine is just old grape juice."
	-- Cookables (x4)
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.FRUIT_SYRUP = "Maybe it would be good with meat."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.MOLASSES = "Very sweet, but still not meat."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.OLEO = "This would be bested by butter in battle." -- Literary reference: "Butter Battle Book" : by Doctor Seuss
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.CASSEROLE = "It has meat in it. But is it meat?"
	-- Crops & Seeds
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.GRAPRICOT = "Balls of fruit."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.GRAPRICOT_COOKED = "Stewed fruit balls."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.GRAPRICOT_SEEDS = "Tiny nature bits."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.LIMON = "Interesting, but I don't like fruit."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.LIMON_COOKED = "I still don't like fruit."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.LIMON_SEEDS = "Tiny nature bits."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.TOMANGO = "It might make a good sauce."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.TOMANGO_COOKED = "I don't like vegetables... or fruit... or vegetables."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.TOMANGO_SEEDS = "Tiny nature bits."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.YAMION = "It might be good with some meat or fish."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.YAMION_COOKED = "The odor is a mighty foe."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.YAMION_SEEDS = "Tiny nature bits."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.GARLEEK = "The strong flavor can spice up many meaty meals."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.GARLEEK_COOKED = "A good thing to add to some meat or fish."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.ROCKY_MEAT = "I shale be eating good tonight." 
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.ROCKY_MEAT_COOKED= "This would be better with a roll."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.TENTACLE_MEAT  = "A gooey bit of meat."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.TENTACLE_MEAT_COOKED  = "A taste of ferocity."
	-- Shipwrecked Crops
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.PAPAYANAPPLE = "Armored fruit."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.PAPAYANAPPLE_COOKED = "Defeated fruit."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.ZUCCHILLI = "."
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.ZUCCHILLI_COOKED = "."	
GLOBAL.STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.ZUCCHILLI_SEEDS = "Tiny nature bits."

-- DESCRIPTIONS.WEBBER
	-- Breads (x3)
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.NANA_BREAD = "A bunch of bread."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.FRUIT_MUFFIN = "A berry tasty bread."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.HARDTACK = "They leave a sooty taste in our mouth."
	-- Cakes & Pies (x4)
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.CACTUS_CAKE = "Pretty pokey."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.MERINGUE = "Baked eggs over pie."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.STICKY_BUN = "Should we stick to our diet?"
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.TARTE_TATIN = "Vegetable pie?"
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.SHAMCAKES = "The berries look like eyes. They give me the crepes!"
	-- Candies & Sugars (x4+)
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.CANDIED_BACON = "Buttery sugary salty snacky."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.CANDIED_FRUIT = "We think it may be too sweet."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.CANDIED_NUT = "Glazed and suffused."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.MUSH_MELON = "Grandpa would toast these when we went camping."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.MUSH_MELON_COOKED = "Toasted golden brown."
	-- Eggs (x4)
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.MUSHY_EGGS = "A mushy mess, just like dad did."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.NOPALITO = "Pokey things with egg."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.OMELETTE = "Eggs filled with tasty foods."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.SALAD_EGG = "Mum would make this every week."
	-- Fruits (x4)
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.FRUIT_LEATHER = "Chewy strips of fruit."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.FRUIT_TRUFFLE = "Custard, fruit and cake." -- Fruit Trifle : A desert of layered fruit, cake, pudding, and whipped cream
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.LIMONADE = "Grandpa would drink this with me in the summer."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.LIMONGELO = "We could watch it jiggle all day."
	-- Meats (x4)
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.BRACIOLE = "Rolled up meat log."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.COLDCUTS = "Complete baloney."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.SAUSAGE_GRAVY = "Greasy meaty tasty treaty."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.SWEET_N_SOUR = "Tasty, tangy, fleshy flavor."
	-- Meats (Fish) (x3)
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.STUFFED_TOMANGO = "I've never seen anything like this."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.SURF_N_TURF = "Will these two things taste good together?"
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.FISH_N_CHIPS = "Just like at the pubs back home."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.LOBSTER_FAKED = "With so many legs, why didn't it crawl out of the pot?"
	-- Meats (Poultry) (x3)
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.ROLLATINI = "Rolled up food log."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.PICATTA = "It tastes a little bitter now."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.BEEFALO_WINGS = "Tiny hot wings."
	-- Mushrooms (4+)
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.CITRUS_MUSHROOM = "A sour, earthy, sticky taste."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.MUSHROOM_BURGER = "Much healthier with meat."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.MUSHROOM_MALODY = "Unpleasant mushroom mix."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.MUSHROOM_MEDLEY = "A pleasant mushroom mix."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.MUSHROOM_STEW = "It tastes better than it smells."
	-- Salads (4)
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.SALAD_CARROT = "It is good for our eyes."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.SALAD_GRAPE = "A salad with fruity bits."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.SALAD_WALDORF = "A salad with meaty bits."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.SALAD_YAMION = "A strong smelling salad."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.SALAD_BLOOM = "A colorful salad."
	-- Soups (x5)
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.GAZPACHO = "I wouldnt eat them like this eatiher."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.CACTUS_SOUP = "Mum made soup when I was sick."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.SOUP_CHOWDER = "Poached fish in heavy cream."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.GUMBO = "Spicy soup."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.SOUP_SQUASH = "Liquid pumpkin."
	-- Snacks (x7 +)
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.ALOO_TIKI = "Like crunchy little bugs."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.CHEESE_LOG = "An edible log."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.NUT_BUTTER = "Fatty nut cream."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.PORRIDGE = "Just like mum would make."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.GRUEL = "Almost like dad would make."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.YAMION_RINGS = "The potato thing is now a ring thing."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.POPCORN_BUTTERY = "Without poping corn what would we do on Tuesdays." -- Anthony T. Hicks
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.TWICE_BAKED = "The smell makes our mouth water."
	-- Liquor (x5 +1)
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.LIQUOR = "Grandpa called it a highball."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.DAIQUIRI = "It also has a tiny umbrella." 
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.MARGARITA = "A shot of courage."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.PINA_COLADA = "It has a tiny umbrella."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.VINO = "Grandma used this in her cooking."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.PINT_NOIR = "Grandma used this when she was cooking."
	-- Cookables (x4)
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.FRUIT_SYRUP = "Vital fluids of fruit."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.MOLASSES = "Grandpa said, 'You bet your sweet fanny it's good.'"
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.OLEO = "It's margarinal." -- oleo is another name for margarine
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.CASSEROLE = "So good we cooked it twice."
	-- Crops & Seeds
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.GRAPRICOT = "A bunch of drupes." -- Drupe: Botanical term for a fruit with a single pit or seed
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.GRAPRICOT_COOKED = "Juicy, like bloated ticks."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.GRAPRICOT_SEEDS = "We could grow something with these."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.LIMON = "This does not taste good."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.LIMON_COOKED = "It might start tasting good if we add sugar."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.LIMON_SEEDS = "We could grow something with these."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.TOMANGO = "Mum would pick these from grandpa's garden."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.TOMANGO_COOKED = "I wouldn't eat these when mum made them."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.TOMANGO_SEEDS = "We could grow something with these."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.YAMION = "Grandpa called them earth apples."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.YAMION_COOKED = "The smell makes our eyes water."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.YAMION_SEEDS = "We could grow something with these."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.GARLEEK = "My eyes water just being near it."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.GARLEEK_COOKED = "It smells like grandma's kitchen."
	-- Shipwrecked Crops
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.PAPAYANAPPLE = "More tree food."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.PAPAYANAPPLE_COOKED = "This also just needs a tiny umbrella."
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.ZUCCHILLI = "Ahhh! It Burns!"
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.ZUCCHILLI_COOKED = "Like tiny slices of fire."	
GLOBAL.STRINGS.CHARACTERS.WEBBER.DESCRIBE.ZUCCHILLI_SEEDS = "We could grow something hot with these."
	
-- Grandpa used to have these at the pub.
else end

-- ADD TENTACLE MEAT DROP CHANCE
if GetModConfigData("waiter_meatdrop") > 0 then -- Only do this if Enabled	

		local function TentacleLootHigh(prefab)
			prefab.components.lootdropper:AddChanceLoot('tentacle_meat',0.35)
		end
		local function TentacleLootLow(prefab)
			prefab.components.lootdropper:AddChanceLoot('tentacle_meat',0.15)
		end
		local function AddTentacleLootHigh(prefab)
			TentacleLootHigh(prefab)
		end
		local function AddTentacleLootLow(prefab)
			TentacleLootLow(prefab)
		end

	if GLOBAL.TheSim:GetGameID() ~="DST" then -- Only Do this if a NON - DST games
				
		if GetModConfigData("waiter_meatdrop") == 1 or GetModConfigData("waiter_meatdrop") >2 then	
			AddPrefabPostInit("tentacle", AddTentacleLootHigh)
			if GLOBAL.IsDLCEnabled(GLOBAL.CAPY_DLC) then 
				AddPrefabPostInit("kraken_tentacle", AddTentacleLootHigh)
			end	
		else end		

		if GetModConfigData("waiter_meatdrop") > 1 then	
			AddPrefabPostInit("merm", AddTentacleLootLow)
			if GLOBAL.IsDLCEnabled(GLOBAL.CAPY_DLC) then 
				AddPrefabPostInit("mermfisher", AddTentacleLootHigh)
			end	
		else end

	else end
	
	if GLOBAL.TheSim:GetGameID() =="DST" then -- Only Do this in DST game
		if not GLOBAL.TheNet:GetIsServer() then
			return
		end
		
		if GetModConfigData("waiter_meatdrop") == 1 or GetModConfigData("waiter_meatdrop") >2 then	
			AddPrefabPostInit("tentacle", AddTentacleLootHigh)
			--[[
			if GLOBAL.IsDLCEnabled(GLOBAL.CAPY_DLC) then 
				AddPrefabPostInit("kraken_tentacle", AddTentacleLootHigh)
			end	
			]]
		else end		

		if GetModConfigData("waiter_meatdrop") > 1 then	
			AddPrefabPostInit("merm", AddTentacleLootLow)
			--[[
			if GLOBAL.IsDLCEnabled(GLOBAL.CAPY_DLC) then 
				AddPrefabPostInit("mermfisher", AddTentacleLootHigh)
			end	
			]]
		else end
	
	else end
	
else end


-- ADD ROCKY MEAT DROP CHANCE
if GetModConfigData("waiter_rockydrop") > 0 then -- Only do this if Enabled	

	local W101_ROCKYMEAT = GetModConfigData("waiter_rockydrop")

	if W101_ROCKYMEAT > 0.5 then W101_ROCKYMEAT = 0.5 end
	
	local function RockMeatLoot(prefab) -- 45% none, 45% one, 10% two
		prefab.components.lootdropper:AddChanceLoot("rocky_meat",W101_ROCKYMEAT)
		prefab.components.lootdropper:AddChanceLoot("rocky_meat",W101_ROCKYMEAT*.5)
	end
	local function AddRockMeatLoot(prefab)
		RockMeatLoot(prefab)
	end
	
	if GLOBAL.TheSim:GetGameID() ~="DST" then -- Only do this in Non DST games
		AddPrefabPostInit("rocky", AddRockMeatLoot)
	else end
		
	if GLOBAL.TheSim:GetGameID() =="DST" then -- Only do this in DST games
		if not GLOBAL.TheNet:GetIsServer() then
			return
		end
		
		AddPrefabPostInit("rocky", AddRockMeatLoot)
	else end
	
else end

-- DRYING RACK MODIFICATIONS
if GLOBAL.TheSim:GetGameID() ~="DST" then
-- Add new items to drying rack in Non-DST games
local function ModDryingRack(inst)

	local oldonstartcooking = inst.components.dryer.onstartcooking
	local newstartcooking = function(inst, dryable, ...)
		if dryable == "grapricot" then
		    inst.AnimState:PlayAnimation("drying_pre")
			inst.AnimState:PushAnimation("drying_loop", true)
			inst.AnimState:OverrideSymbol("swap_dried", "grapricot_dried", "grapricot_hanging")
			return
		--end
		elseif dryable == "tomango" then
		    inst.AnimState:PlayAnimation("drying_pre")
			inst.AnimState:PushAnimation("drying_loop", true)
			inst.AnimState:OverrideSymbol("swap_dried", "tomango_dried", "tomango_hanging")
			return
		--end
		elseif dryable == "spiced_sausage" then
		    inst.AnimState:PlayAnimation("drying_pre")
			inst.AnimState:PushAnimation("drying_loop", true)
			inst.AnimState:OverrideSymbol("swap_dried", "spiced_sausage", "sausage_hanging")
		    return
		end

		return oldonstartcooking(inst, dryable, ...)
	end

	local oldoncontinuedone = inst.components.dryer.oncontinuedone
	local newcontinuedone = function(inst, product, ...)
	    if product == "grapricot_dried" then
		    inst.AnimState:PlayAnimation("idle_full")
		    inst.AnimState:OverrideSymbol("swap_dried", "grapricot_dried", "grapricot_dried_hanging")
		return
		--end
		elseif product == "tomango_dried" then
		    inst.AnimState:PlayAnimation("idle_full")
		    inst.AnimState:OverrideSymbol("swap_dried", "tomango_dried", "tomangodried")
		  return
		--end
		elseif product == "sausage_dried" then
		    inst.AnimState:PlayAnimation("idle_full")
		    inst.AnimState:OverrideSymbol("swap_dried", "spiced_sausage", "sausage_drying")
		  return
	end

	    return oldoncontinuedone(inst, product, ...)
	end

    inst.components.dryer:SetStartDryingFn(newstartcooking)
    inst.components.dryer:SetContinueDryingFn(newstartcooking)
	inst.components.dryer:SetDoneDryingFn(newcontinuedone)
    inst.components.dryer:SetContinueDoneFn(newcontinuedone)
end
AddPrefabPostInit("meatrack", ModDryingRack)

else end

if GLOBAL.TheSim:GetGameID() =="DST" then

-- Insert dryable into "berries_juicy"
AddPrefabPostInit("berries_juicy", function(inst)
		inst:AddComponent("dryable")
		inst.components.dryable:SetProduct("grapricot_dried")
		inst.components.dryable:SetDryTime(TUNING.DRY_MED)
end)

--[[ 
TUNING.DRY_FAST = small meat or monster meat, adds ~8 healing and ~10 sanity vs cooked version
TUNING.DRY_MED = large meat, adds ~16 healing and ~15 sanity vs cooked version
]]

if not GLOBAL.TheNet:GetIsServer() then
		return
end

-- Add new items to drying rack in DST games

local function ModDSTDryingRack(inst)

	local oldonstartdrying = inst.components.dryer.onstartdrying
	local newstartdrying = function(inst, dryable, ...)
		if dryable == "grapricot" then
		    inst.AnimState:PlayAnimation("drying_pre")
			inst.AnimState:PushAnimation("drying_loop", true)
			inst.AnimState:OverrideSymbol("swap_dried", "grapricot_dried", "grapricot_hanging")
			return
		--end
		elseif dryable == "tomango" then
		    inst.AnimState:PlayAnimation("drying_pre")
			inst.AnimState:PushAnimation("drying_loop", true)
			inst.AnimState:OverrideSymbol("swap_dried", "tomango_dried", "tomango_hanging")
			return
		--end
		elseif dryable == "spiced_sausage" then
		    inst.AnimState:PlayAnimation("drying_pre")
			inst.AnimState:PushAnimation("drying_loop", true)
			inst.AnimState:OverrideSymbol("swap_dried", "spiced_sausage", "sausage_hanging")
			return
		--end
		elseif dryable == "berries_juicy" then
		    inst.AnimState:PlayAnimation("drying_pre")
			inst.AnimState:PushAnimation("drying_loop", true)
			inst.AnimState:OverrideSymbol("swap_dried", "grapricot_dried", "j_berries_hanging")
			return
		end

		return oldonstartdrying(inst, dryable, ...)
	end

	local oldondonedrying = inst.components.dryer.ondonedrying
	local newdonedrying = function(inst, product, ...)
	    if product == "grapricot_dried" then
		    inst.AnimState:PlayAnimation("idle_full")
		    inst.AnimState:OverrideSymbol("swap_dried", "grapricot_dried", "grapricot_dried_hanging")
			return
		--end
		elseif product == "tomango_dried" then
		    inst.AnimState:PlayAnimation("idle_full")
		    inst.AnimState:OverrideSymbol("swap_dried", "tomango_dried", "tomangodried")
		return
		--end
		elseif product == "sausage_dried" then
		    inst.AnimState:PlayAnimation("idle_full")
		    inst.AnimState:OverrideSymbol("swap_dried", "spiced_sausage", "sausage_drying")
		return
	    end
		
	    return oldondonedrying(inst, product, ...)
	end

    inst.components.dryer:SetStartDryingFn(newstartdrying)
	inst.components.dryer:SetDoneDryingFn(newdonedrying)
-- these don't seem to be used in DST
	-- inst.components.dryer:SetContinueDryingFn(newstartdrying)
	-- inst.components.dryer:SetContinueDoneFn(newdonedrying)

end

AddPrefabPostInit("meatrack", ModDSTDryingRack)
else end
print "@@@ Waiter101 Modmain END @@@"