-- require "prefabutil"

local assets =
{
	Asset("ANIM", "anim/mooncake_simple.zip"),
    Asset("ATLAS", "images/inventoryimages/mooncake_simple.xml"),
	Asset("INV_IMAGE", "mooncake_simple"),
	Asset("INV_IMAGE", "mooncakenew"),
	Asset("INV_IMAGE", "mooncakequarter"),
	Asset("INV_IMAGE", "mooncakehalf"),
	Asset("INV_IMAGE", "mooncakethreequarter"),
	Asset("INV_IMAGE", "mooncakefull"),
	
}

local prefabs = 
{
	"spoiled_food",
	"mooncake_simple",
}

local lightstate =
{
	_simple				= {brightness=0.00,   enabled=false,  radius=0.00},
    new                 = {brightness=0.00,   enabled=false,  radius=0.00},
    quarter             = {brightness=0.00,   enabled=false,  radius=0.00},
    half                = {brightness=0.00,   enabled=false,  radius=0.00},
    threequarter        = {brightness=0.50,   enabled=true,   radius=0.30},
    full                = {brightness=0.50,   enabled=true,   radius=0.60},
}

local function SetPhase()
if TheSim:GetGameID()=="DST" then

	local W101_PHASE = TheWorld.state.moonphase
	return W101_PHASE -- returns value of W101_PHASE
	else 	
	local W101_CLOCK = GetClock()
	local W101_PHASE = W101_CLOCK and GetClock():GetMoonPhase() or "_simple"
	return W101_PHASE -- returns value of W101_PHASE
end
end
	
local function OnEaten(inst, eater)

	local W101_PHASE = SetPhase() -- sets variable equal to return from SetPhase function
		
	if eater:HasTag("player") then
		if W101_PHASE == "full" and math.random() < 0.70 then
			eater.components.inventory:GiveItem(SpawnPrefab("mooncake_simple"))
		elseif W101_PHASE == "new" and math.random() < 0.10 then
			eater.components.inventory:GiveItem(SpawnPrefab("mooncake_simple"))
		elseif W101_PHASE ~="new" and W101_PHASE ~="full" and math.random() < 0.35 then
			eater.components.inventory:GiveItem(SpawnPrefab("mooncake_simple"))
		end
	end
end

local function UpdateImages(inst)

	local W101_PHASE = SetPhase() -- sets variable equal to return from SetPhase function

	inst.components.inventoryitem:ChangeImageName("mooncake"..tostring(W101_PHASE))
		
end

local function OnMoonPhaseChange(inst)

	local W101_PHASE = SetPhase() -- sets variable equal to return from SetPhase function
		
	if W101_PHASE == "full" then
		inst.Light:SetDisableOnSceneRemoval(false)
	else
		inst.Light:SetDisableOnSceneRemoval(true)
	end

    -- inst.Light:Enable(false)
	
	local lightstate = lightstate[W101_PHASE]
	inst.Light:SetIntensity(lightstate.brightness)
    inst.Light:Enable(lightstate.enabled)
    inst.Light:SetRadius(lightstate.radius)
	
	UpdateImages(inst)

end

local function fn(Sim)
	local inst = CreateEntity()
	inst.entity:AddTransform()
	inst.entity:AddAnimState()
	inst.entity:AddLight()
	if TheSim:GetGameID() =="DST" then inst.entity:AddNetwork() end

	MakeInventoryPhysics(inst)
	MakeSmallBurnable(inst)
	MakeSmallPropagator(inst)
		
	if W101_FLOAT == 1 then
		MakeInventoryFloatable(inst, "idle_water", "idle")	 
		MakeBlowInHurricane(inst, TUNING.WINDBLOWN_SCALE_MIN.LIGHT, TUNING.WINDBLOWN_SCALE_MAX.LIGHT)
	else end
	
	inst.AnimState:SetBank("mooncake_simple")
	inst.AnimState:SetBuild("mooncake_simple")
	inst.AnimState:PlayAnimation("idle")
	
	inst:AddTag("preparedfood")

	if W101_DST_FLOAT==1 then
	    MakeInventoryFloatable(inst, "small", 0.2, 0.95)
	end
		
	inst.Light:Enable(false)
	inst.Light:SetFalloff(.3)
	inst.Light:SetIntensity(0.0)
    inst.Light:SetColour(180 / 255, 160 / 255, 240 / 255)
    inst.Light:SetDisableOnSceneRemoval(true)
		
	if TheSim:GetGameID()=="DST" then
		if not TheWorld.ismastersim then
			return inst
		end
		
		inst.entity:SetPristine()
	end
			
	inst:AddComponent("edible")
	inst.components.edible.foodtype = "VEGGIE"
	inst.components.edible.foodstate = "PREPARED"
	inst.components.edible.healthvalue = TUNING.HEALING_MED
	inst.components.edible.hungervalue = TUNING.CALORIES_LARGE
	inst.components.edible.sanityvalue = TUNING.SANITY_TINY
	inst.components.edible:SetOnEatenFn(OnEaten)

	inst:AddComponent("inspectable")

	inst:AddComponent("inventoryitem")
	inst.components.inventoryitem.atlasname = "images/inventoryimages/mooncake_simple.xml"
			
	inst:AddComponent("stackable")
	inst.components.stackable.maxsize = TUNING.STACK_SIZE_SMALLITEM

	inst:AddComponent("perishable")
	inst.components.perishable:SetPerishTime(TUNING.PERISH_SUPERFAST)
	inst.components.perishable:StartPerishing()
	inst.components.perishable.onperishreplacement = "spoiled_food"

	inst:AddComponent("bait")
	inst:AddComponent("tradable")
	inst.components.tradable.goldvalue = 1
	inst.components.tradable.dubloonvalue = 3
	
	OnMoonPhaseChange(inst)
		
	if TheSim:GetGameID()=="DST" then
		inst:WatchWorldState("moonphase", OnMoonPhaseChange)
		MakeHauntableLaunchAndPerish(inst)
	else
		inst:ListenForEvent("daytime", function(global, data)
		OnMoonPhaseChange(inst)
		end, GetWorld())
	end
		
    return inst

end

return Prefab( "common/inventory/mooncake_simple", fn, assets, prefabs )