--require "prefabs/veggies"
-- ==========================================================================================

local function MakeVegStats(seedweight, hunger, health, perish_time, sanity, cooked_hunger, cooked_health, cooked_perish_time, cooked_sanity, id, true_name)
	return 
	{
		health = health,
		hunger = hunger,
		cooked_health = cooked_health,
		cooked_hunger = cooked_hunger,
		seed_weight = seedweight,
		perishtime = perish_time,
		cooked_perishtime = cooked_perish_time,
		sanity = sanity,
		cooked_sanity = cooked_sanity,
		id = id,
		name = true_name,
	}
end

local COMMON = 3
local FREQUENT = 2
local UNCOMMON = 1
local INFREQUENT = .75
local RARE = .5
local VERYRARE = .3

local WAITER_CROPS =
    {
        grapricot = MakeVegStats(FREQUENT,    TUNING.CALORIES_SMALL,    TUNING.HEALING_TINY,    TUNING.PERISH_FAST, 0,
            TUNING.CALORIES_TINY,    TUNING.HEALING_SMALL,    TUNING.PERISH_SUPERFAST, 0, 11, "grapricot"),
 
		--Also Grows in viney bush [SW]
		tomango = MakeVegStats(INFREQUENT,    TUNING.CALORIES_MEDSMALL,    TUNING.HEALING_SMALL,    TUNING.PERISH_FAST, 0,
            TUNING.CALORIES_SMALL,    TUNING.HEALING_MEDSMALL,    TUNING.PERISH_SUPERFAST, 0, 12, "tomango"),
			
        limon = MakeVegStats(INFREQUENT,    TUNING.CALORIES_SMALL,    TUNING.HEALING_MEDSMALL,    TUNING.PERISH_FAST, 0,
            TUNING.CALORIES_SMALL,    TUNING.HEALING_SMALL,    TUNING.PERISH_SUPERFAST, TUNING.SANITY_SUPERTINY, 13, "limon"),

		yamion = MakeVegStats(FREQUENT,    TUNING.CALORIES_SMALL,    TUNING.HEALING_SMALL,    TUNING.PERISH_MED, 0,
            TUNING.CALORIES_SMALL,    TUNING.HEALING_SMALL,    TUNING.PERISH_FAST, 0, 14, "yamion"),
	
		-- Also drops from Lumpy Evergreen and Spiky Trees	
		guavacado = MakeVegStats(RARE,	TUNING.CALORIES_MED,	 TUNING.HEALING_SMALL,	TUNING.PERISH_SUPERFAST,	0,
			TUNING.CALORIES_MEDSMALL,	 TUNING.HEALING_MEDSMALL,	TUNING.PERISH_SUPERFAST, TUNING.SANITY_SUPERTINY, 15, "guavacado"),	
			
		--Also Grows in Wild
		rutabeeta = MakeVegStats(FREQUENT,	TUNING.CALORIES_SMALL,	 TUNING.HEALING_TINY,	TUNING.PERISH_FAST,	0,
			TUNING.CALORIES_SMALL,	 TUNING.HEALING_TINY*2,	TUNING.PERISH_SUPERFAST,	0, 16, "rutabeeta"),
		
		--Also Grows in viney bush [SW]
		zucchilli = MakeVegStats(RARE,	TUNING.CALORIES_MEDSMALL,	 TUNING.HEALING_MEDSMALL,	TUNING.PERISH_MED,	-TUNING.SANITY_SUPERTINY*2,
			TUNING.CALORIES_MEDSMALL,	 TUNING.HEALING_SMALL,	TUNING.PERISH_SUPERFAST,	-TUNING.SANITY_SUPERTINY, 17, "zucchilli"),
		
--[[
		--NOT SEEDABLE - Grows with grass tufts (also grows in transplanted tufts)
		garleek = MakeVegStats(0,    TUNING.CALORIES_TINY,    TUNING.HEALING_TINY,    TUNING.PERISH_SLOW, -TUNING.SANITY_TINY,
            TUNING.CALORIES_TINY,    TUNING.HEALING_TINY,    TUNING.PERISH_FAST, 0, 18, "garleek"),
			
		--NOT SEEDABLE - Grows in jungle trees [SW]
		papayanapple = MakeVegStats(0,    TUNING.CALORIES_SMALL,    TUNING.HEALING_SMALL,    TUNING.PERISH_SLOW*0.5, 0,
            TUNING.CALORIES_TINY,    TUNING.HEALING_TINY,    TUNING.PERISH_SUPERFAST, TUNING.SANITY_TINY*0.5, 19, "papayanapple"),
]]			
	}
	
local function MakeVeggie(name, has_seeds)

	local assets =
	{	
		Asset("ANIM", "anim/"..name..".zip"),
		Asset("IMAGE", "images/inventoryimages/"..name..".tex"),
		Asset("ATLAS", "images/inventoryimages/"..name..".xml"),
		
		Asset("ANIM", "anim/"..name.."_cooked.zip"),
		Asset("IMAGE", "images/inventoryimages/"..name.."_cooked.tex"),
		Asset("ATLAS", "images/inventoryimages/"..name.."_cooked.xml"),
		Asset("IMAGE", "images/inventoryimages/"..name.."_seeds.tex"),
		Asset("ATLAS", "images/inventoryimages/"..name.."_seeds.xml"),
		
--[[
		Asset("IMAGE", "images/inventoryimages/tomango.tex"),
		Asset("ATLAS", "images/inventoryimages/tomango.xml"),
		Asset("IMAGE", "images/inventoryimages/tomango_cooked.tex"),
		Asset("ATLAS", "images/inventoryimages/tomango_cooked.xml"),
		Asset("IMAGE", "images/inventoryimages/tomango_seeds.tex"),
		Asset("ATLAS", "images/inventoryimages/tomango_seeds.xml"),
				
		Asset("IMAGE", "images/inventoryimages/rutabeeta.tex"),
		Asset("ATLAS", "images/inventoryimages/rutabeeta.xml"),
		Asset("IMAGE", "images/inventoryimages/rutabeeta_cooked.tex"),
		Asset("ATLAS", "images/inventoryimages/rutabeeta_cooked.xml"),
		Asset("IMAGE", "images/inventoryimages/rutabeeta_seeds.tex"),
		Asset("ATLAS", "images/inventoryimages/rutabeeta_seeds.xml"),
		
		Asset("IMAGE", "images/inventoryimages/yamion.tex"),
		Asset("ATLAS", "images/inventoryimages/yamion.xml"),
		Asset("IMAGE", "images/inventoryimages/yamion_cooked.tex"),
		Asset("ATLAS", "images/inventoryimages/yamion_cooked.xml"),
		Asset("IMAGE", "images/inventoryimages/yamion_seeds.tex"),
		Asset("ATLAS", "images/inventoryimages/yamion_seeds.xml"),
		
		Asset("IMAGE", "images/inventoryimages/guavacado.tex"),
		Asset("ATLAS", "images/inventoryimages/guavacado.xml"),
		Asset("IMAGE", "images/inventoryimages/guavacado_cooked.tex"),
		Asset("ATLAS", "images/inventoryimages/guavacado_cooked.xml"),
		Asset("IMAGE", "images/inventoryimages/guavacado_seeds.tex"),
		Asset("ATLAS", "images/inventoryimages/guavacado_seeds.xml"),
		
		Asset("IMAGE", "images/inventoryimages/limon.tex"),
		Asset("ATLAS", "images/inventoryimages/limon.xml"),
		Asset("IMAGE", "images/inventoryimages/limon_cooked.tex"),
		Asset("ATLAS", "images/inventoryimages/limon_cooked.xml"),
		Asset("IMAGE", "images/inventoryimages/limon_seeds.tex"),
		Asset("ATLAS", "images/inventoryimages/limon_seeds.xml"),
		
		Asset("IMAGE", "images/inventoryimages/grapricot.tex"),
		Asset("ATLAS", "images/inventoryimages/grapricot.xml"),
		Asset("IMAGE", "images/inventoryimages/grapricot_cooked.tex"),
		Asset("ATLAS", "images/inventoryimages/grapricot_cooked.xml"),
		Asset("IMAGE", "images/inventoryimages/grapricot_seeds.tex"),
		Asset("ATLAS", "images/inventoryimages/grapricot_seeds.xml"),
		
		Asset("IMAGE", "images/inventoryimages/zucchilli.tex"),
		Asset("ATLAS", "images/inventoryimages/zucchilli.xml"),
		Asset("IMAGE", "images/inventoryimages/zucchilli_cooked.tex"),
		Asset("ATLAS", "images/inventoryimages/zucchilli_cooked.xml"),
		Asset("IMAGE", "images/inventoryimages/zucchilli_seeds.tex"),
		Asset("ATLAS", "images/inventoryimages/zucchilli_seeds.xml"),
	]]
		
--[[ Asset("IMAGE", "images/inventoryimages/garleek.tex"),
		Asset("ATLAS", "images/inventoryimages/garleek.xml"),
		Asset("IMAGE", "images/inventoryimages/garleek_cooked.tex"),
		Asset("ATLAS", "images/inventoryimages/garleek_cooked.xml"),

		Asset("IMAGE", "images/inventoryimages/papayanapple.tex"),
		Asset("ATLAS", "images/inventoryimages/papayanapple.xml"),
		Asset("IMAGE", "images/inventoryimages/papayanapple_cooked.tex"),
		Asset("ATLAS", "images/inventoryimages/papayanapple_cooked.xml"),
	]]	
		
	}

	local assets_cooked = {}

	local assets_seeds = {}
		
	local prefabs =
	{	
		name.."_cooked",
		"spoiled_food",
	}
	
	if has_seeds then
		table.insert(prefabs, name.."_seeds")
	end

	local function fn_seeds()
		local inst = CreateEntity()

		inst.entity:AddTransform()
		inst.entity:AddAnimState()
	    
		MakeInventoryPhysics(inst)

        inst.AnimState:SetBank("seeds")
        inst.AnimState:SetBuild("seeds")
        inst.AnimState:SetRayTestOnBB(true)
		inst.AnimState:PlayAnimation("idle")
		
		if W101_FLOAT==1 then
			MakeInventoryFloatable(inst, "idle_water", "idle")
			MakeBlowInHurricane(inst, TUNING.WINDBLOWN_SCALE_MIN.LIGHT, TUNING.WINDBLOWN_SCALE_MAX.LIGHT)
		end

		if W101_DST_FLOAT==1 then
		    MakeInventoryFloatable(inst, "small", 0.2, 0.95)
		end
		-- ++++++++++++++++++++++++++++++++++
		if TheSim:GetGameID()=="DST" then
			inst.entity:AddNetwork()
			inst.entity:SetPristine()
			if not TheWorld.ismastersim then
		    	return inst
			end
		end
		-- ++++++++++++++++++++++++++++++++++
		
		inst:AddComponent("edible")
		inst.components.edible.healthvalue 	= TUNING.HEALING_TINY/2
		inst.components.edible.hungervalue 	= TUNING.CALORIES_TINY
		inst.components.edible.foodtype 	= "SEEDS"
		inst.components.edible.foodstate 	= "RAW"

        inst:AddComponent("stackable")
		inst.components.stackable.maxsize = TUNING.STACK_SIZE_SMALLITEM

		inst:AddComponent("tradable")
		inst:AddComponent("inspectable")
		inst:AddComponent("inventoryitem")
	    inst.components.inventoryitem.imagename = name.."_seeds"
	    inst.components.inventoryitem.atlasname = "images/inventoryimages/"..name.."_seeds.xml"

		inst:AddComponent("perishable")
		inst.components.perishable:SetPerishTime(TUNING.PERISH_SUPERSLOW)
		inst.components.perishable:StartPerishing()
		inst.components.perishable.onperishreplacement = "spoiled_food"

		inst:AddComponent("cookable")
		inst.components.cookable.product = "seeds_cooked"

		inst:AddComponent("bait")

		inst:AddComponent("plantable")
		inst.components.plantable.growtime = TUNING.SEEDS_GROW_TIME
		inst.components.plantable.product = name

	if TheSim:GetGameID()=="DST" then
		MakeHauntableLaunchAndPerish(inst)
	else end
	
		return inst
	end

	local function fn()
		local inst = CreateEntity()

		inst.entity:AddTransform()
		inst.entity:AddAnimState()

		MakeInventoryPhysics(inst)

		inst.AnimState:SetBank(name)
		inst.AnimState:SetBuild(name)
		inst.AnimState:PlayAnimation("idle")
		
		if W101_FLOAT==1 then
			MakeInventoryFloatable(inst,"idle_water","idle")
			MakeBlowInHurricane(inst, TUNING.WINDBLOWN_SCALE_MIN.LIGHT, TUNING.WINDBLOWN_SCALE_MAX.LIGHT)
		end
		
		if W101_DST_FLOAT==1 then
		    MakeInventoryFloatable(inst, "small", 0.2, 0.95)
		end
		
		-- ++++++++++++++++++++++++++++++++++
		if TheSim:GetGameID()=="DST" then
			inst.entity:AddNetwork()
			inst.entity:SetPristine()
			if not TheWorld.ismastersim then
		    	return inst
			end
		end
		-- ++++++++++++++++++++++++++++++++++
		
		inst:AddComponent("edible")
		inst.components.edible.healthvalue 	= WAITER_CROPS[name].health
		inst.components.edible.hungervalue 	= WAITER_CROPS[name].hunger
		inst.components.edible.sanityvalue 	= WAITER_CROPS[name].sanity or 0		
		inst.components.edible.foodtype 	= "VEGGIE"
		inst.components.edible.foodstate 	= "RAW"

        inst:AddComponent("stackable")
		inst.components.stackable.maxsize = TUNING.STACK_SIZE_SMALLITEM

		inst:AddComponent("tradable")
		inst:AddComponent("inspectable")
		inst:AddComponent("inventoryitem")
	    inst.components.inventoryitem.imagename = name
	    inst.components.inventoryitem.atlasname = "images/inventoryimages/"..name..".xml"

		inst:AddComponent("perishable")
		inst.components.perishable:SetPerishTime(WAITER_CROPS[name].perishtime)
		inst.components.perishable:StartPerishing()
		inst.components.perishable.onperishreplacement = "spoiled_food"   

		local coldmeds = name == "tomango" or name == "grapricot" or name == "limon"
		if coldmeds then
			if W101_MEDS== 1 then
				if name == "limon" then
			inst.components.edible.antihistamine = 240 -- 1/2 day -- limon
					elseif name == "tomango" then
				inst.components.edible.antihistamine = 190 -- 2/5 day -- tomango
					else
				inst.components.edible.antihistamine = 80 -- 1/6 day -- grapricot
				end
			end
		end
		
		local can_dry = name == "grapricot" or name == "tomango"
		if can_dry then
			inst:AddComponent("dryable")
			inst.components.dryable:SetProduct(name.."_dried")
			inst.components.dryable:SetDryTime(TUNING.DRY_MED)
		end
		
		local hot_pepper = name == "zucchilli"
		if hot_pepper then
			if W101_TEMP == 1 then 
			inst.components.edible.temperaturedelta = TUNING.HOT_FOOD_BONUS_TEMP*1.25
			inst.components.edible.temperatureduration = TUNING.FOOD_TEMP_AVERAGE*2
			else end
		end
		
		inst:AddComponent("bait")

		inst:AddComponent("cookable")
		inst.components.cookable.product = name.."_cooked"

	    MakeSmallBurnable(inst)
		MakeSmallPropagator(inst) 
	
	if TheSim:GetGameID()=="DST" then
		MakeHauntableLaunchAndPerish(inst)
	else end
	
	return inst
	end
	
	local function fn_cooked()
		local inst = CreateEntity()

		inst.entity:AddTransform()
		inst.entity:AddAnimState()

		MakeInventoryPhysics(inst)
		
		inst.AnimState:SetBank(name.."_cooked")
		inst.AnimState:SetBuild(name.."_cooked")
		inst.AnimState:PlayAnimation("idle")
		
		if W101_FLOAT==1 then
			MakeInventoryFloatable(inst,"idle_water","idle")
			MakeBlowInHurricane(inst, TUNING.WINDBLOWN_SCALE_MIN.LIGHT, TUNING.WINDBLOWN_SCALE_MAX.LIGHT)
		end
		
		if W101_DST_FLOAT==1 then
		    MakeInventoryFloatable(inst, "small", 0.2, 0.95)
		end
		
		-- ++++++++++++++++++++++++++++++++++
		if TheSim:GetGameID()=="DST" then
			inst.entity:AddNetwork()
			inst.entity:SetPristine()
			if not TheWorld.ismastersim then
		    	return inst
			end
		end
		-- ++++++++++++++++++++++++++++++++++
		
		inst:AddComponent("edible")
		inst.components.edible.healthvalue = WAITER_CROPS[name].cooked_health
		inst.components.edible.hungervalue = WAITER_CROPS[name].cooked_hunger
		inst.components.edible.sanityvalue = WAITER_CROPS[name].cooked_sanity or 0
		inst.components.edible.foodtype = "VEGGIE"
		inst.components.edible.foodstate = "COOKED"

        inst:AddComponent("stackable")
		inst.components.stackable.maxsize = TUNING.STACK_SIZE_SMALLITEM

		inst:AddComponent("tradable")
		inst:AddComponent("inspectable")
		inst:AddComponent("inventoryitem")
	    inst.components.inventoryitem.imagename = name.."_cooked"
	    inst.components.inventoryitem.atlasname = "images/inventoryimages/"..name.."_cooked.xml"

		inst:AddComponent("perishable")
		inst.components.perishable:SetPerishTime(WAITER_CROPS[name].cooked_perishtime)
		inst.components.perishable:StartPerishing()
		inst.components.perishable.onperishreplacement = "spoiled_food"
	
		local coldmeds = name == "tomango" or name == "grapricot" or name == "limon"
		if coldmeds then
			if W101_MEDS == 1 then
				if name == "grapricot" then
				inst.components.edible.antihistamine = 160 -- 1/3 day -- grapricot_cooked
					elseif name == "limon" then
				inst.components.edible.antihistamine = 120 --  1/4 day -- limon_cooked
					else
				inst.components.edible.antihistamine = 100 -- 1/6 day -- tomango_cooked
				end
			end
		end
			
		local hot_pepper = name == "zucchilli"
		if hot_pepper then
			if W101_TEMP == 1 then 
			inst.components.edible.temperaturedelta = TUNING.HOT_FOOD_BONUS_TEMP*1.5
			inst.components.edible.temperatureduration = TUNING.FOOD_TEMP_LONG
			else end
		end
		
		inst:AddComponent("bait")

	    MakeSmallBurnable(inst)
		MakeSmallPropagator(inst)

	if TheSim:GetGameID()=="DST" then
		MakeHauntableLaunchAndPerish(inst)
	else end
		return inst
	end
	
	local raw = Prefab( "common/inventory/"..name, fn, assets, prefabs)
	local cooked = Prefab( "common/inventory/"..name.."_cooked", fn_cooked, assets)
	local seeds = has_seeds and Prefab( "common/inventory/"..name.."_seeds", fn_seeds, assets) or nil
	return raw, cooked, seeds
	
	end	

local prefs = {}
for veggiename,veggiedata in pairs(WAITER_CROPS) do
	local veg, cooked, seeds

	veg, cooked, seeds = MakeVeggie(veggiename, true)

	table.insert(prefs, veg)
	table.insert(prefs, cooked)
	if W101_CROPS == 1 and seeds then
		table.insert(prefs, seeds)
		VEGGIES[veggiename] = veggiedata
	end
	
end

return unpack(prefs)