-- REVISED ADD INGREDIENTS PROCESS, Thanks to DarkXero and Serpens66 for code assist
local require = GLOBAL.require
local cooking = require("cooking")
local ingredients = cooking.ingredients

--NOTE: If the thing already had a tag with the same name, you will still overwrite the old value, unless keepoldvalues is true. E.g if fish already had a tag seafood with value 0.5 and now you use this function with value 1, the result will be 1.

function InsertIngredientValues(names, tags, cancook, candry, keepoldvalues) -- if cancook or candry is true, the cooked/dried variant of the thing will also get the tags and the tags precook/dried.
	for _,name in pairs(names) do
        if ingredients[name] == nil then -- if it is not cookable already, it will be nil. Following code is just a copy of the normal InsertIngredientValues function
            ingredients[name] = { tags= {}}

            if cancook then
                ingredients[name.."_cooked"] = {tags={}}
            end

            if candry then
                ingredients[name.."_dried"] = {tags={}}
            end

            for tagname,tagval in pairs(tags) do
                ingredients[name].tags[tagname] = tagval
                --print(name,tagname,tagval,ingtable[name].tags[tagname])

                if cancook then
                    ingredients[name.."_cooked"].tags.precook = 1
                    ingredients[name.."_cooked"].tags[tagname] = tagval
                end
                if candry then
                    ingredients[name.."_dried"].tags.dried = 1
                    ingredients[name.."_dried"].tags[tagname] = tagval
                end
            end
        else    -- but if there are already some tags, don't delete previous tags, just add the new ones. 
            for tagname,tagval in pairs(tags) do
                if ingredients[name].tags[tagname]==nil or not keepoldvalues then -- only overwrite old value, if there is no old value, or if keepoldvalues is not true (will be not true by default)
                    ingredients[name].tags[tagname] = tagval -- this will overwrite the old value, if there was one
                end
                --print(name,tagname,tagval,ingtable[name].tags[tagname])

                if cancook then
                    if ingredients[name.."_cooked"] == nil then
                        ingredients[name.."_cooked"] = {tags={}}
                    end
                    if ingredients[name.."_cooked"].tags.precook==nil or not keepoldvalues then
                        ingredients[name.."_cooked"].tags.precook = 1
                    end
                    if ingredients[name.."_cooked"].tags[tagname]==nil or not keepoldvalues then
                        ingredients[name.."_cooked"].tags[tagname] = tagval
                    end
                end
                if candry then
                    if ingredients[name.."_dried"] == nil then
                        ingredients[name.."_dried"] = {tags={}}
                    end
                    if ingredients[name.."_dried"].tags.dried==nil or not keepoldvalues then
                        ingredients[name.."_dried"].tags.dried = 1
                    end
                    if ingredients[name.."_dried"].tags[tagname]==nil or not keepoldvalues then    
                        ingredients[name.."_dried"].tags[tagname] = tagval
                    end
                end
            end
        end
	end
end

--[[
LIST OF TAGS used in WAITER 101
Not sure if you can make use of this information, but here it is: <MR>

ALKALINE TAG (Sea vegetables and ingredients from nightshade family that have alkaloids) = Tomango, Eggplant, Seaweed
CITRUS TAG (Ingredient containing citric acid) = Limon, Papayanapple, Cooked Grapricots (1/2)
DAIRY TAG (Milk, Butter, and similar substitutes) = Milk, Butter, Oleo, Coconut Milk (1/2)
FAT TAG (Ingredients with high fat content) = Coconut, Butter, Oleo, Blubber, Guavacado
FLOUR TAG (cooking flour) = Flour_Ground
FLORA TAG (flowers, and other plant materials) = Petals, Foliage, Succulents, Uncooked Seaweed
FUNGUS TAG (ingredients that are fungus, including mold, spores, and lichen) = blue/green/red cap, lichen
INEDIBLE TAG (ingredients that are not edible by themselves or normally uncookable) = Foliage, Petals, Twigs
LEEK TAG (Ingredients from the Allium genus, onion, garlic, etc) = Yamion, Garleek
MUSHROOMS TAG (ingredients that are specifically mushrooms) = blue/green/red cap
NUT TAG (Ingredients that are nuts) = Birchnut, Coconut_halved (1/2)
POULTRY TAG (Meats derived from Bird or Winged creatures) = Batilisk Wings, Drumsticks
PRECOOK TAG (Any ingredient that has already been cooked, such as over a campfire) 
PUNGENT TAG (Ingredients with strong odors) = Garleek, Limon, Durian
ROOT TAG (Ingredients that are root vegetables) = Carrot, Rutabeeta
SEAFOOD TAG (All shellfish (see below), fish, amphibians, and sea born veggies) = Eel, Fish, Froglegs (1/2), Seaweed (1/2), etc.
SEED TAG (Crop seeds as well as plantable nuts) = Birchnut, Seeds
SHELLFISH TAG (Aquatic animals with a shell or carapace) = Lobster, Crab, Mussels (1/2), Limpets (1/2)
SPICES TAG (Things with strong 'heat' have the spices tag) = Garleek, Zucchilli
SQUASH TAG (Ingredients that are gourd or gourd-like) = Zucchilli, Pumpkin
STARCH TAG (High starch ingredients) = Sweet Potato, Yamion, Corn, Banana, Pumpkin (1/2)
TUBER TAG (Stem tuber roots) = Sweet Potato, Yamion
WRAPPER TAG (Dried Seaweed, Eel, Tentacle) other foodstuffs that can be used to wrap things in.

other tags used = berries, yam, onion, lime, lemon, tomato, mango, grapes, apricot, zucchini, chili, pepper (the vegetable)*,
papaya, pineapple, guava, avocado, rutabaga, beet, banana, cave_banana, rawmilk
* would suggest 'peppercorn' for the spice if needed

OTHER MODs TAGS
tag.beefalo_rawmilk = unpasturized beefalo milk
tag.ox_rawmilk = unpasturized ox milk (waterbeefalo from shipwrecked)
-- pasturized beefalo_milk and ox_milk are {tag.dairy = 0.5}
tag.sour_milk = curd, (I am assuming milk spoils to curds)
tag.dairy_yellow = hard cheese, used for pizza
tag.dairy_white = soft cheese, used for cheesecake

]]
-- InsertIngredientValues(names, tags, cancook, candry, keepoldvalues)
-- EXAMPLE: InsertIngredientValues({"fish", "eel"}, {meat=0.5, fish=1, seafood=1},true,false,true)

-- This should force to numerical for old saves
W101_WINGS = GetModConfigData("waiter_cookablewings") + 0	
W101_PETALS = GetModConfigData("waiter_cookablepetals") + 0
W101_SEEDS = GetModConfigData("waiter_cookableseeds") + 0
W101_WOBSTER = GetModConfigData("waiter_cookablewobster") + 0
W101_BLUBBER = GetModConfigData("waiter_cookableblubber") + 0
W101_PLANTMEAT = GetModConfigData("waiter_cookableplantmeat") + 0
-- This should force to numerical for old saves

function ingredientpostinit()
-- ADD ACK_MUFFIN MASTER TAG LIST 
-- The Ack Muffin is a Macguffin placeholder for tags that may not be in game, allows adding recipes for non existing tags that may otherwise cause crashes
InsertIngredientValues({"ack_muffin"}, {cactus=1, jell=1, pineapple=0.5, roe=1, coconut=1, caffeine=1, frozen=1, squash=1, root=1, bulb=1, challa=1, cacao_cooked=1, nut=1, jellyfish=1 },false,false,false)

-- Make Cookable
if W101_WINGS > 0 then	
InsertIngredientValues({"batwing"}, {meat=0.5, monster=0.5, wings=1, poultry=1},true,false,false)
else end

if W101_PLANTMEAT > 0 then	
InsertIngredientValues({"plantmeat"}, {veggie=0.5, monster= 1, meat= 0.5},true,false,false)
else end

if W101_PETALS > 0 then	
InsertIngredientValues({"petals"}, {flora=1, decoration=0.5, inedible=0.5},false,false,false)
InsertIngredientValues({"petals_evil"}, {flora=1, monster= 0.5, inedible=0.5},false,false,false)

else end
-- Add Seed TAG
if W101_SEEDS > 0 and W101_SEEDS < 3 then	
InsertIngredientValues({"seeds","carrot_seeds","corn_seeds","dragonfruit_seeds","durian_seeds","eggplant_seeds","pomegranate_seeds","pumpkin_seeds"}, {seed=0.5},false,false,false)
else end

-- ADD CUSTOM CROPS - (names, tags, cancook, candry, keepoldvalues)
InsertIngredientValues({"grapricot"}, {fruit=0.5, berries=1, grapes=0.5, apricot=0.5, grapricot=1}, false,false,false)
InsertIngredientValues({"grapricot_cooked"}, {fruit=0.5, berries=1, citrus=0.5, grapes=0.5, apricot=0.5, grapricot=1, precook=1}, false,false,false)
InsertIngredientValues({"grapricot_dried"}, {fruit=0.5, berries=1, dried=1, apricot=0.5, grapricot=1}, false,false,false)
InsertIngredientValues({"limon"}, {fruit=1, citrus=1, pungent=1, antihistamine=0.5, lemon=0.5, lime=0.5, limon=1}, false,false,false)
InsertIngredientValues({"limon_cooked"}, {fruit=1, citrus=1, pungent=1, precook=1, lemon=0.5, lime=0.5, limon=1}, false,false,false)
InsertIngredientValues({"tomango"}, {fruit=1, alkaline=1, veggie=1, tomato=0.5, mango=0.5, tomango=1}, true,false,false)
InsertIngredientValues({"tomango_dried"}, {fruit=1, alkaline=1, antihistamine=0.5, veggie=1, tomato=0.5, mango=0.5, tomango=1}, false,false,false)
InsertIngredientValues({"guavacado"}, {fruit=1, fat=0.5, guava=0.5, avacado=0.5, guavacado=1}, true,false,false)
InsertIngredientValues({"guavacado"}, {wrapper=1}, false,false,false) -- adds wrapper tag to guavacado (thin sliced cucumber can be used as Gunkan Maki )
InsertIngredientValues({"yamion"}, {veggie=1, leek=1, starch=1, tuber=1, onion=0.5, yam=0.5, yamion=1}, true,false,false)
InsertIngredientValues({"zucchilli"}, {veggie=1, squash=1, spices=1, zucchini=0.5, chili=0.5, pepper=0.5, zucchilli=1}, false,false,false)
InsertIngredientValues({"zucchilli_cooked"}, {veggie=1, spices=1, zucchini=0.5, chili=0.5, pepper=0.5, zucchilli=1, precook=1}, false,false,false)
InsertIngredientValues({"rocky_meat"}, {seafood=0.5, shellfish=0.5, stone=1, monster=0.5}, true,false,false)
InsertIngredientValues({"rutabeeta"}, {root=1, flora=0.5, veggie=0.5, rutabaga=0.5, beet=0.5, rutabeeta=1}, true,false,true)

if W101_SEEDS > 0 and W101_SEEDS < 3 then	
InsertIngredientValues({"grapricot_seeds","rutabeeta_seeds","guavacado_seeds","limon_seeds","tomango_seeds","yamion_seeds"}, {seed=0.5}, false,false,false)
InsertIngredientValues({"zucchilli_seeds"}, {spices=1, seed=0.5}, false,false,false)

else end

-- ADD CUSTOM DROPS
InsertIngredientValues({"garleek"}, {veggie=0.5, leek=0.5, garlic=0.5, garleek=1, pungent=1, spices=1}, true,false,false)
InsertIngredientValues({"tentacle_meat"}, {meat=0.5, monster=0.5, seafood=1}, true,false,false)
InsertIngredientValues({"tentacle_meat"}, {wrapper=1}, false,false,false)

-- ADD CUSTOM INGREDIENTS 
InsertIngredientValues({"oleo"}, {dairy=1, fat=1}, false,false,false)
InsertIngredientValues({"molasses"}, {sweetener=2}, false,false,false)
InsertIngredientValues({"fruit_syrup"}, {fruit=0.5, sweetener=1}, false,false,false)
InsertIngredientValues({"casserole"}, {meat=0.5, veggie=0.5, precook=3}, false,false,false)
InsertIngredientValues({"spiced_sausage"}, {meat=1, spices=1, bratwurst=1, precook=1}, false,false,false)
InsertIngredientValues({"sausage_cooked"}, {meat=1, spices=0.5, bratwurst=1, precook=2}, false,false,false)
InsertIngredientValues({"sausage_dried"}, {meat=1, dried=1, bratwurst=1, precook=1}, false,false,false)
InsertIngredientValues({"flour_ground"}, {flour=1}, false,false,false)		
		
-- ADD FUNGUS & MUSHROOM TAG - (names, tags, cancook, candry, keepoldvalues)
InsertIngredientValues({"cutlichen"}, {fungus=1},false,false,false)
InsertIngredientValues({"blue_cap"}, {fungus=1, mushrooms=1, blue_cap=1},true,false,true)
InsertIngredientValues({"green_cap"}, {fungus=1, mushrooms=1, green_cap=1},true,false,true)
InsertIngredientValues({"red_cap"}, {fungus=1, mushrooms=1, red_cap=1},true,false,true)

-- ADD POULTRY TAG (meats from winged creatures are poultry)
InsertIngredientValues({"drumstick"}, {poultry=1}, true,false,true)

-- ADD SEAFOOD TAG (aquatic or amphibious animal products have the seafood tag)
InsertIngredientValues({"fish", "eel"}, {seafood=1}, true,false,true)
InsertIngredientValues({"eel"}, {wrapper=1}, false,false,true) -- adds wrapper tag to uncooked eel
InsertIngredientValues({"froglegs"}, {seafood=0.5}, true,false,true)

-- ADD PUNGENT TAG (Things with strong odors have the pungent tag)
InsertIngredientValues({"durian"}, {pungent=1}, true,false,true)

-- ADD STARCH TAG
InsertIngredientValues({"corn"}, {starch=1, corn=1}, true,false,true)
InsertIngredientValues({"cave_banana"}, {starch=1, banana=1}, true,false,true)
InsertIngredientValues({"pumpkin"}, {starch=0.5, squash=1}, true,false,true)

-- Add Misc TAGs - (names, tags, cancook, candry, keepoldvalues)
InsertIngredientValues({"foliage"}, {flora=1},false,false,false)
InsertIngredientValues({"carrot"}, {root=1}, true,false,true)
InsertIngredientValues({"eggplant"}, {alkaline=1}, true,false,true)
InsertIngredientValues({"berries"}, {berries=1}, true,false,true)

-- ADD Tags to Third Party Modded Foods
InsertIngredientValues({"hybrid_banana"}, {starch=1, banana=1}, true,false,true) -- attempt to allow hybrid_banana to be used for banana recipes
InsertIngredientValues({"lime"}, {citrus=1}, true,false,true) -- attempt to add citrus tag to lemon from Tiny Alchemy Powers
InsertIngredientValues({"truffles"}, {fungus=1, mushrooms=1}, true,false,true) -- attempt to add fungus and mushroom tags to truffles from Tiny Alchemy Powers
InsertIngredientValues({"tater"}, {starch=1, tuber=1}, true,true,true) -- Makes this starch in "CAMP CUISINE" mod
InsertIngredientValues({"yam"}, {starch=1, tuber=1}, true,true,true) -- Makes this starch in "CAMP CUISINE" mod
InsertIngredientValues({"saurkraut"}, {pungent=1}, true,true,true) -- Makes this pungent in "CAMP CUISINE" mod

-- ADD DST Food tags - (names, tags, cancook, candry, keepoldvalues)
InsertIngredientValues({"rock_avocado_fruit_ripe"}, {avacado=1, stone=1}, true,false,true) 


end

function dlcingredientpostinit() --RoG Ingredients
-- RoG make cookable
if W101_SEEDS > 0 and W101_SEEDS < 3 then	
InsertIngredientValues({"watermelon_seeds"}, {seed=0.5}, false,false,false)
else end
InsertIngredientValues({"watermelon"}, {melon=1, watermelon=1}, true,false,true)

-- ADD RoG NUT TAG
InsertIngredientValues({"acorn_cooked"}, {nut=1}, false,false,false)

-- ADD RoG CACTUS TAG
InsertIngredientValues({"cactus_meat"}, {cactus=1}, true,false,true)

-- ADD RoG DECORATION TAG
InsertIngredientValues({"cactus_flower"}, {decoration=1}, false,false,true)

end

function swingredientpostinit() -- Shpwrecked Ingredients
-- SHIPWRECKED Make Cookable
if W101_WOBSTER > 0 then	
InsertIngredientValues({"lobster_dead"}, {fish=1, seafood=1, shellfish=1}, false,false,false)
InsertIngredientValues({"lobster_dead_cooked"}, {fish=0.5, seafood=0.5, shellfish=1, precook=2}, false,false,false)
InsertIngredientValues({"dorsalfin"}, {seafood=1}, false,false,false)
else end
if W101_BLUBBER > 0 then
InsertIngredientValues({"blubber"}, {seafood=0.5, fat=2, monster=1}, false,false,false)
else end

-- ADD SHIPWRECKED CUSTOM DROPS
InsertIngredientValues({"papayanapple"}, {fruit=1, antihistamine=0.5, papaya=0.5, pineapple=0.5, papayanapple=1, citrus=1}, false,false,false)
InsertIngredientValues({"papayanapple_cooked"}, {fruit=1, precook=1, papaya=0.5, pineapple=0.5, papayanapple=1, citrus=1}, false,false,false)

-- ADD SHIPWRECKED CUSTOM INGREDIENTS
InsertIngredientValues({"coconut_milk"}, {coconut=0.5, dairy=0.5}, false,false,true)

-- ADD TAGs to SWEET POTATO
InsertIngredientValues({"sweet_potato"}, {starch=1, tuber=1}, true,false,true)
if W101_SEEDS > 0 and W101_SEEDS < 3 then	
InsertIngredientValues({"sweet_potato_seeds"}, {seed=0.5}, false,false,false)
else end
-- ADD TAGs to COCONUT
InsertIngredientValues({"coconut_halved", "coconut_cooked"}, {coconut=0.5, nut=0.5}, false,false,true)

-- ADD ALKALINE TAG (Ingredients that have strong alkaline/salty flavor)
InsertIngredientValues({"seaweed"}, {alkaline=0.5, seafood=0.5, wrapper=1 }, true,true,true) -- wrapper tag to all types of seaweed (cooked, dried, raw) 
InsertIngredientValues({"seaweed"}, {flora=0.5}, false,false,true) -- seaweed also counts as 'flora' when uncooked.

-- ADD SEAFOOD TAG (aquatic or amphibious animal products have the seafood tag)
InsertIngredientValues({"fish_raw", "tropical_fish", "solofish", "shark_fin", "fish_med_cooked", "jellyjerky"}, {seafood=1}, false,false,true)
InsertIngredientValues({"fish3", "fish4", "fish5"}, {seafood=1}, true,false,true)
InsertIngredientValues({"jellyfish"}, {seafood=1, jell=1}, true,false,true)
InsertIngredientValues({"jellyfish_dead"}, {seafood=1, jell=1}, false,false,true)
InsertIngredientValues({"rainbowjellyfish"}, {fish=1, jellyfish=1, decoration=1, seafood=1, jell=1}, true,false,true)
InsertIngredientValues({"rainbowjellyfish_dead"}, {fish=1, jellyfish=1, decoration=1, seafood=1, jell=1}, false,false,true)

InsertIngredientValues({"fish_raw_small", "roe"}, {seafood=0.5}, true,false,true)
InsertIngredientValues({"roe"}, {roe=1}, true,false,true)

-- ADD SHELLFISH & SEAFOOD TAG (aquatic or amphibious animals that have a shell or caripace)
InsertIngredientValues({"limpets", "mussel"}, {seafood=0.5, shellfish=0.5}, true,false,true)
InsertIngredientValues({"crab"}, {seafood=1, shellfish=1}, false,false,true)
InsertIngredientValues({"lobster"}, {seafood=1, shellfish=2}, false,false,true)

-- ADD CAFFEINE TAG (Ingredients containing caffeine, if a dish provides speed boost it should cause sanity loss)
InsertIngredientValues({"coffeebeans"}, {caffeine=1}, true,false,true)

end

function HAMingredientpostinit() -- Hamlet Ingredients
--InsertIngredientValues({"asparagus"}, {veggie=1}, true,false,true)
InsertIngredientValues({"radish"}, {root=1}, true,false,true)
InsertIngredientValues({"piko_salsa"}, {spices=1, antihistamine=0.5, veggie=1}, false,false,false)
--Cookable Tea Tree seed pod
if W101_SEEDS > 0 and W101_SEEDS < 3 then	
InsertIngredientValues({"aloe_seeds", "asparagus_seeds", "radish_seeds"}, {seed=0.5}, false,false,false)
end
if W101_SEEDS == 1 or W101_SEEDS == 3 then	
InsertIngredientValues({"teatree_nut_cooked"}, {antihistamine=0.5, seed=1, caffeine=0.5}, false,false,false)
end
--InsertIngredientValues({"teatree_nut"}, {seed=1, caffeine=0.5}, true,false,true)
--Cookable Tubers
--InsertIngredientValues({"tuber_bloom_crop"}, {starch=1, tuber=1}, true,false,true)
--InsertIngredientValues({"tuber_crop"}, {starch=1, tuber=1, toxic=1}, true,false,true)
--Cookable Poison Dart Froglegs
--InsertIngredientValues({"froglegs_poison"}, {seafood=0.5, meat=0.5, toxic=1}, true,false,true)

--InsertIngredientValues({"cutnettle"}, {antihistamine=1}, false,false,true)
--InsertIngredientValues({"snake_bone"}, {bone=1}, false,false,true)


-- NOTE: Can NOT tag piko_orange as MEAT or it breaks tea recipe
--InsertIngredientValues({"piko_orange"}, {filter=1}, false,false,true)
InsertIngredientValues({"piko"}, {meat=0.5}, false,false,true) -- must tag piko as something to use in salsa
InsertIngredientValues({"slugbug"}, {bug=1, jell=1, toxic=1}, false,false,true)
InsertIngredientValues({"jellybug"}, {bug=1, legume=1}, true,false,true)
InsertIngredientValues({"weevole_carapace"}, {inedible=1, shell=1}, false,false,true)
end

-- NAMES, TAGS, CANCOOK, CANDRY, KEEPOLDVALUES

function dstingredientpostinit() -- DST only Ingredients

InsertIngredientValues({"berries_juicy"}, {grapes=1, berries=1}, true,false,true)

if W101_PETALS > 0 then	
InsertIngredientValues({"succulent_picked"}, {flora=1, decoration=0.5},false,false,false)
else end

end

if GLOBAL.TheSim:GetGameID()~="DST" then

	if GLOBAL.IsDLCEnabled(GLOBAL.CAPY_DLC) then -- add Shipwrecked and RoG Ingredient Tags
		swingredientpostinit()
		dlcingredientpostinit()
	else end

	if GLOBAL.IsDLCEnabled(GLOBAL.PORKLAND_DLC) then -- add Hamlet, Shipwrecked and RoG Ingredient Tags
        HAMingredientpostinit()
		swingredientpostinit()
		dlcingredientpostinit()
	else end

else end


if GLOBAL.IsDLCEnabled(GLOBAL.REIGN_OF_GIANTS) or GLOBAL.TheSim:GetGameID()=="DST" then -- add RoG Ingredient Tags
    dlcingredientpostinit() else
end

if GLOBAL.TheSim:GetGameID()=="DST" then -- add DST Only Ingredient Tags
	dstingredientpostinit() else
end

ingredientpostinit() -- add all core game Ingredient Tags

--[[
Glow Berries "wormlight" - Berries, ?? 0.5 fruit? monster? decoration? inedible?
Lesser Glow Berries "wormlight_lesser" - Berries, ?? 0.5 fruit?, decoration? monster? inedible? grows on plants 
Glow Bulbs "lightbulb" - IRL Floral Bulbs include Lily and Tulip 
- flora? decoration? regrows in 3 days - very prolific, inedible? Fungus (not really)? 
]]